summaryrefslogtreecommitdiffstats
path: root/korganizer/kodialogmanager.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/kodialogmanager.cpp')
-rw-r--r--korganizer/kodialogmanager.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/korganizer/kodialogmanager.cpp b/korganizer/kodialogmanager.cpp
index 11f01aa5..ff26d005 100644
--- a/korganizer/kodialogmanager.cpp
+++ b/korganizer/kodialogmanager.cpp
@@ -19,8 +19,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#include <kcmultidialog.h>
@@ -90,8 +90,8 @@ KODialogManager::KODialogManager( CalendarView *mainView ) :
mFilterEditDialog = 0;
mCategoryEditDialog = new KPIM::CategoryEditDialog( KOPrefs::instance(), mMainView );
// don't set any specific parent for the dialog, as its kept around and reused
// in different cases where it should have different parents
KWin::setMainWindow( mCategoryEditDialog, 0 );
connect( mainView, TQT_SIGNAL( categoriesChanged() ),
mCategoryEditDialog, TQT_SLOT( reload() ) );
@@ -108,9 +108,9 @@ KODialogManager::~KODialogManager()
delete mFilterEditDialog;
}
-void KODialogManager::errorSaveIncidence( TQWidget *parent, Incidence *incidence )
+void KODialogManager::errorSaveIncidence( TQWidget *tqparent, Incidence *incidence )
{
- KMessageBox::sorry( parent, i18n("Unable to save %1 \"%2\".")
+ KMessageBox::sorry( tqparent, i18n("Unable to save %1 \"%2\".")
.arg( i18n( incidence->type() ) )
.arg( incidence->summary() ) );
}
@@ -90,8 +90,8 @@ KODialogManager::KODialogManager( CalendarView *mainView ) :
mFilterEditDialog = 0;
mCategoryEditDialog = new KPIM::CategoryEditDialog( KOPrefs::instance(), mMainView );
- // don't set any specific parent for the dialog, as its kept around and reused
- // in different cases where it should have different parents
+ // don't set any specific tqparent for the dialog, as its kept around and reused
+ // in different cases where it should have different tqparents
KWin::setMainWindow( mCategoryEditDialog, 0 );
connect( mainView, TQT_SIGNAL( categoriesChanged() ),